function Rec = Fil2str(InputFileName)
%
% Assembly of the information in the ABAQUS results file
% 
% Syntax
%     #Rec# = Fil2str(#InputFileName#);
%
% Description
%     Assemble the information contained in an ABAQUS results (*.fil) file
%     in ASCII format into a string that has one row.
%     The following option with parameter has to be specified in the ABAQUS
%     input file for the results (*.fil) file to be created:
%         ...
%         *FILE FORMAT, ASCII
%         ...
%     NOTE: The results file (*.fil) must be placed in the same directory
%     with the MATLAB source files in order to be processed.
%     
% Input parameters
%     #InputFileName# (string) is a string containing the name of the
%         ABAQUS results (*.fil) file, along with its extension. The
%         results file is generated by Abaqus after the analysis has been
%         completed.
% 
% Output parameters
%     #Rec# ([1 x #m#]) is a string containing the information of the
%         Abaqus results file assembled in one row.
%
% _________________________________________________________________________
% Copyright (c) 2016
%     George Papazafeiropoulos
%     Captain, Infrastructure Engineer, Hellenic Air Force
%     Civil Engineer, M.Sc., Ph.D. candidate, NTUA
%     Email: gpapazafeiropoulos@yahoo.gr
%     Website: http://users.ntua.gr/gpapazaf/
%


% Read the input file
fileID = fopen(InputFileName,'r');
C = textscan (fileID, '%s', 'CollectOutput', '1', 'delimiter', ...
    '','whitespace','','endofline','');
fclose(fileID);
% Initialize A
A=cell(1,1);
% Remove newline characters
A{1}=regexprep(C{1}{1},'\r\n|\n|\r','');
% Convert from cell to char
Rec=char(A);

end


